package main

import (
	"app-cloudep-notification-service/gen_result/pb/notification"
	"app-cloudep-notification-service/internal/config"
	senderserviceServer "app-cloudep-notification-service/internal/server/senderservice"
	"app-cloudep-notification-service/internal/svc"
	"flag"
	"log"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/core/service"
	"github.com/zeromicro/go-zero/zrpc"
	"google.golang.org/grpc"
	"google.golang.org/grpc/reflection"
)

var configFile = flag.String("f", "etc/notification.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)
	ctx := svc.NewServiceContext(c)

	s := zrpc.MustNewServer(c.RpcServerConf, func(grpcServer *grpc.Server) {
		notification.RegisterSenderServiceServer(grpcServer, senderserviceServer.NewSenderServiceServer(ctx))

		if c.Mode == service.DevMode || c.Mode == service.TestMode {
			reflection.Register(grpcServer)
		}
	})
	defer s.Stop()

	log.Printf("Starting rpc server at %s...\n", c.ListenOn)
	s.Start()
}
